# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ComplianceFrameworkArgs', 'ComplianceFramework']

@pulumi.input_type
class ComplianceFrameworkArgs:
    def __init__(__self__, *,
                 color: pulumi.Input[builtins.str],
                 description: pulumi.Input[builtins.str],
                 namespace_path: pulumi.Input[builtins.str],
                 default: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 pipeline_configuration_full_path: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a ComplianceFramework resource.
        :param pulumi.Input[builtins.str] color: New color representation of the compliance framework in hex format. e.g. #FCA121.
        :param pulumi.Input[builtins.str] description: Description for the compliance framework.
        :param pulumi.Input[builtins.str] namespace_path: Full path of the namespace to add the compliance framework to.
        :param pulumi.Input[builtins.bool] default: Set this compliance framework as the default framework for the group. Default: `false`
        :param pulumi.Input[builtins.str] name: Name for the compliance framework.
        :param pulumi.Input[builtins.str] pipeline_configuration_full_path: Full path of the compliance pipeline configuration stored in a project repository, such as `.gitlab/.compliance-gitlab-ci.yml@compliance/hipaa`. Required format: `path/file.y[a]ml@group-name/project-name` **Note**: Ultimate license required.
        """
        pulumi.set(__self__, "color", color)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "namespace_path", namespace_path)
        if default is not None:
            pulumi.set(__self__, "default", default)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if pipeline_configuration_full_path is not None:
            pulumi.set(__self__, "pipeline_configuration_full_path", pipeline_configuration_full_path)

    @property
    @pulumi.getter
    def color(self) -> pulumi.Input[builtins.str]:
        """
        New color representation of the compliance framework in hex format. e.g. #FCA121.
        """
        return pulumi.get(self, "color")

    @color.setter
    def color(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "color", value)

    @property
    @pulumi.getter
    def description(self) -> pulumi.Input[builtins.str]:
        """
        Description for the compliance framework.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="namespacePath")
    def namespace_path(self) -> pulumi.Input[builtins.str]:
        """
        Full path of the namespace to add the compliance framework to.
        """
        return pulumi.get(self, "namespace_path")

    @namespace_path.setter
    def namespace_path(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "namespace_path", value)

    @property
    @pulumi.getter
    def default(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Set this compliance framework as the default framework for the group. Default: `false`
        """
        return pulumi.get(self, "default")

    @default.setter
    def default(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "default", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Name for the compliance framework.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="pipelineConfigurationFullPath")
    def pipeline_configuration_full_path(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Full path of the compliance pipeline configuration stored in a project repository, such as `.gitlab/.compliance-gitlab-ci.yml@compliance/hipaa`. Required format: `path/file.y[a]ml@group-name/project-name` **Note**: Ultimate license required.
        """
        return pulumi.get(self, "pipeline_configuration_full_path")

    @pipeline_configuration_full_path.setter
    def pipeline_configuration_full_path(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "pipeline_configuration_full_path", value)


@pulumi.input_type
class _ComplianceFrameworkState:
    def __init__(__self__, *,
                 color: Optional[pulumi.Input[builtins.str]] = None,
                 default: Optional[pulumi.Input[builtins.bool]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 framework_id: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 namespace_path: Optional[pulumi.Input[builtins.str]] = None,
                 pipeline_configuration_full_path: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering ComplianceFramework resources.
        :param pulumi.Input[builtins.str] color: New color representation of the compliance framework in hex format. e.g. #FCA121.
        :param pulumi.Input[builtins.bool] default: Set this compliance framework as the default framework for the group. Default: `false`
        :param pulumi.Input[builtins.str] description: Description for the compliance framework.
        :param pulumi.Input[builtins.str] framework_id: Globally unique ID of the compliance framework.
        :param pulumi.Input[builtins.str] name: Name for the compliance framework.
        :param pulumi.Input[builtins.str] namespace_path: Full path of the namespace to add the compliance framework to.
        :param pulumi.Input[builtins.str] pipeline_configuration_full_path: Full path of the compliance pipeline configuration stored in a project repository, such as `.gitlab/.compliance-gitlab-ci.yml@compliance/hipaa`. Required format: `path/file.y[a]ml@group-name/project-name` **Note**: Ultimate license required.
        """
        if color is not None:
            pulumi.set(__self__, "color", color)
        if default is not None:
            pulumi.set(__self__, "default", default)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if framework_id is not None:
            pulumi.set(__self__, "framework_id", framework_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if namespace_path is not None:
            pulumi.set(__self__, "namespace_path", namespace_path)
        if pipeline_configuration_full_path is not None:
            pulumi.set(__self__, "pipeline_configuration_full_path", pipeline_configuration_full_path)

    @property
    @pulumi.getter
    def color(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        New color representation of the compliance framework in hex format. e.g. #FCA121.
        """
        return pulumi.get(self, "color")

    @color.setter
    def color(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "color", value)

    @property
    @pulumi.getter
    def default(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Set this compliance framework as the default framework for the group. Default: `false`
        """
        return pulumi.get(self, "default")

    @default.setter
    def default(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "default", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Description for the compliance framework.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="frameworkId")
    def framework_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Globally unique ID of the compliance framework.
        """
        return pulumi.get(self, "framework_id")

    @framework_id.setter
    def framework_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "framework_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Name for the compliance framework.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="namespacePath")
    def namespace_path(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Full path of the namespace to add the compliance framework to.
        """
        return pulumi.get(self, "namespace_path")

    @namespace_path.setter
    def namespace_path(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "namespace_path", value)

    @property
    @pulumi.getter(name="pipelineConfigurationFullPath")
    def pipeline_configuration_full_path(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Full path of the compliance pipeline configuration stored in a project repository, such as `.gitlab/.compliance-gitlab-ci.yml@compliance/hipaa`. Required format: `path/file.y[a]ml@group-name/project-name` **Note**: Ultimate license required.
        """
        return pulumi.get(self, "pipeline_configuration_full_path")

    @pipeline_configuration_full_path.setter
    def pipeline_configuration_full_path(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "pipeline_configuration_full_path", value)


class ComplianceFramework(pulumi.CustomResource):

    pulumi_type = "gitlab:index/complianceFramework:ComplianceFramework"

    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 color: Optional[pulumi.Input[builtins.str]] = None,
                 default: Optional[pulumi.Input[builtins.bool]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 namespace_path: Optional[pulumi.Input[builtins.str]] = None,
                 pipeline_configuration_full_path: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        The `ComplianceFramework` resource allows to manage the lifecycle of a compliance framework on top-level groups.

        There can be only one `default` compliance framework. Of all the configured compliance frameworks marked as default, the last one applied will be the default compliance framework.

        > This resource requires a GitLab Enterprise instance with a Premium license to create the compliance framework.

        > This resource requires a GitLab Enterprise instance with an Ultimate license to specify a compliance pipeline configuration in the compliance framework.

        **Upstream API**: [GitLab GraphQL API docs](https://docs.gitlab.com/api/graphql/reference/#mutationcreatecomplianceframework)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        sample = gitlab.ComplianceFramework("sample",
            namespace_path="top-level-group",
            name="HIPAA",
            description="A HIPAA Compliance Framework",
            color="#87BEEF",
            default=False,
            pipeline_configuration_full_path=".hipaa.yml@top-level-group/compliance-frameworks")
        ```

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_compliance_framework`. For example:

        terraform

        import {

          to = gitlab_compliance_framework.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        Gitlab compliance frameworks can be imported with a key composed of `<namespace_path>:<framework_id>`, e.g.

        ```sh
        $ pulumi import gitlab:index/complianceFramework:ComplianceFramework sample "top-level-group:gid://gitlab/ComplianceManagement::Framework/12345"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] color: New color representation of the compliance framework in hex format. e.g. #FCA121.
        :param pulumi.Input[builtins.bool] default: Set this compliance framework as the default framework for the group. Default: `false`
        :param pulumi.Input[builtins.str] description: Description for the compliance framework.
        :param pulumi.Input[builtins.str] name: Name for the compliance framework.
        :param pulumi.Input[builtins.str] namespace_path: Full path of the namespace to add the compliance framework to.
        :param pulumi.Input[builtins.str] pipeline_configuration_full_path: Full path of the compliance pipeline configuration stored in a project repository, such as `.gitlab/.compliance-gitlab-ci.yml@compliance/hipaa`. Required format: `path/file.y[a]ml@group-name/project-name` **Note**: Ultimate license required.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ComplianceFrameworkArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `ComplianceFramework` resource allows to manage the lifecycle of a compliance framework on top-level groups.

        There can be only one `default` compliance framework. Of all the configured compliance frameworks marked as default, the last one applied will be the default compliance framework.

        > This resource requires a GitLab Enterprise instance with a Premium license to create the compliance framework.

        > This resource requires a GitLab Enterprise instance with an Ultimate license to specify a compliance pipeline configuration in the compliance framework.

        **Upstream API**: [GitLab GraphQL API docs](https://docs.gitlab.com/api/graphql/reference/#mutationcreatecomplianceframework)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        sample = gitlab.ComplianceFramework("sample",
            namespace_path="top-level-group",
            name="HIPAA",
            description="A HIPAA Compliance Framework",
            color="#87BEEF",
            default=False,
            pipeline_configuration_full_path=".hipaa.yml@top-level-group/compliance-frameworks")
        ```

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_compliance_framework`. For example:

        terraform

        import {

          to = gitlab_compliance_framework.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        Gitlab compliance frameworks can be imported with a key composed of `<namespace_path>:<framework_id>`, e.g.

        ```sh
        $ pulumi import gitlab:index/complianceFramework:ComplianceFramework sample "top-level-group:gid://gitlab/ComplianceManagement::Framework/12345"
        ```

        :param str resource_name: The name of the resource.
        :param ComplianceFrameworkArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ComplianceFrameworkArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 color: Optional[pulumi.Input[builtins.str]] = None,
                 default: Optional[pulumi.Input[builtins.bool]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 namespace_path: Optional[pulumi.Input[builtins.str]] = None,
                 pipeline_configuration_full_path: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ComplianceFrameworkArgs.__new__(ComplianceFrameworkArgs)

            if color is None and not opts.urn:
                raise TypeError("Missing required property 'color'")
            __props__.__dict__["color"] = color
            __props__.__dict__["default"] = default
            if description is None and not opts.urn:
                raise TypeError("Missing required property 'description'")
            __props__.__dict__["description"] = description
            __props__.__dict__["name"] = name
            if namespace_path is None and not opts.urn:
                raise TypeError("Missing required property 'namespace_path'")
            __props__.__dict__["namespace_path"] = namespace_path
            __props__.__dict__["pipeline_configuration_full_path"] = pipeline_configuration_full_path
            __props__.__dict__["framework_id"] = None
        super(ComplianceFramework, __self__).__init__(
            'gitlab:index/complianceFramework:ComplianceFramework',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            color: Optional[pulumi.Input[builtins.str]] = None,
            default: Optional[pulumi.Input[builtins.bool]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            framework_id: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            namespace_path: Optional[pulumi.Input[builtins.str]] = None,
            pipeline_configuration_full_path: Optional[pulumi.Input[builtins.str]] = None) -> 'ComplianceFramework':
        """
        Get an existing ComplianceFramework resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] color: New color representation of the compliance framework in hex format. e.g. #FCA121.
        :param pulumi.Input[builtins.bool] default: Set this compliance framework as the default framework for the group. Default: `false`
        :param pulumi.Input[builtins.str] description: Description for the compliance framework.
        :param pulumi.Input[builtins.str] framework_id: Globally unique ID of the compliance framework.
        :param pulumi.Input[builtins.str] name: Name for the compliance framework.
        :param pulumi.Input[builtins.str] namespace_path: Full path of the namespace to add the compliance framework to.
        :param pulumi.Input[builtins.str] pipeline_configuration_full_path: Full path of the compliance pipeline configuration stored in a project repository, such as `.gitlab/.compliance-gitlab-ci.yml@compliance/hipaa`. Required format: `path/file.y[a]ml@group-name/project-name` **Note**: Ultimate license required.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ComplianceFrameworkState.__new__(_ComplianceFrameworkState)

        __props__.__dict__["color"] = color
        __props__.__dict__["default"] = default
        __props__.__dict__["description"] = description
        __props__.__dict__["framework_id"] = framework_id
        __props__.__dict__["name"] = name
        __props__.__dict__["namespace_path"] = namespace_path
        __props__.__dict__["pipeline_configuration_full_path"] = pipeline_configuration_full_path
        return ComplianceFramework(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def color(self) -> pulumi.Output[builtins.str]:
        """
        New color representation of the compliance framework in hex format. e.g. #FCA121.
        """
        return pulumi.get(self, "color")

    @property
    @pulumi.getter
    def default(self) -> pulumi.Output[builtins.bool]:
        """
        Set this compliance framework as the default framework for the group. Default: `false`
        """
        return pulumi.get(self, "default")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        Description for the compliance framework.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="frameworkId")
    def framework_id(self) -> pulumi.Output[builtins.str]:
        """
        Globally unique ID of the compliance framework.
        """
        return pulumi.get(self, "framework_id")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        Name for the compliance framework.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="namespacePath")
    def namespace_path(self) -> pulumi.Output[builtins.str]:
        """
        Full path of the namespace to add the compliance framework to.
        """
        return pulumi.get(self, "namespace_path")

    @property
    @pulumi.getter(name="pipelineConfigurationFullPath")
    def pipeline_configuration_full_path(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Full path of the compliance pipeline configuration stored in a project repository, such as `.gitlab/.compliance-gitlab-ci.yml@compliance/hipaa`. Required format: `path/file.y[a]ml@group-name/project-name` **Note**: Ultimate license required.
        """
        return pulumi.get(self, "pipeline_configuration_full_path")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ProjectJobTokenScopesArgs', 'ProjectJobTokenScopes']

@pulumi.input_type
class ProjectJobTokenScopesArgs:
    def __init__(__self__, *,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 project: Optional[pulumi.Input[builtins.str]] = None,
                 project_id: Optional[pulumi.Input[builtins.int]] = None,
                 target_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]] = None,
                 target_project_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]] = None):
        """
        The set of arguments for constructing a ProjectJobTokenScopes resource.
        :param pulumi.Input[builtins.bool] enabled: Enable the given inbound allowlist. If false, will allow any project or group regardless of the values in `target_project_ids` or `target_group_ids`. Deleting the associated `ProjectJobTokenScopes` resource will reset `Enabled` on the group to `true`.
        :param pulumi.Input[builtins.str] project: The ID or full path of the project.
        :param pulumi.Input[builtins.int] project_id: The ID of the project.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.int]]] target_group_ids: A set of group IDs that are in the CI/CD job token inbound allowlist.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.int]]] target_project_ids: A set of project IDs that are in the CI/CD job token inbound allowlist.
        """
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if project_id is not None:
            warnings.warn("""`project_id` has been deprecated. Use `project` instead.""", DeprecationWarning)
            pulumi.log.warn("""project_id is deprecated: `project_id` has been deprecated. Use `project` instead.""")
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if target_group_ids is not None:
            pulumi.set(__self__, "target_group_ids", target_group_ids)
        if target_project_ids is not None:
            pulumi.set(__self__, "target_project_ids", target_project_ids)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Enable the given inbound allowlist. If false, will allow any project or group regardless of the values in `target_project_ids` or `target_group_ids`. Deleting the associated `ProjectJobTokenScopes` resource will reset `Enabled` on the group to `true`.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID or full path of the project.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter(name="projectId")
    @_utilities.deprecated("""`project_id` has been deprecated. Use `project` instead.""")
    def project_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The ID of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "project_id", value)

    @property
    @pulumi.getter(name="targetGroupIds")
    def target_group_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]]:
        """
        A set of group IDs that are in the CI/CD job token inbound allowlist.
        """
        return pulumi.get(self, "target_group_ids")

    @target_group_ids.setter
    def target_group_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]]):
        pulumi.set(self, "target_group_ids", value)

    @property
    @pulumi.getter(name="targetProjectIds")
    def target_project_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]]:
        """
        A set of project IDs that are in the CI/CD job token inbound allowlist.
        """
        return pulumi.get(self, "target_project_ids")

    @target_project_ids.setter
    def target_project_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]]):
        pulumi.set(self, "target_project_ids", value)


@pulumi.input_type
class _ProjectJobTokenScopesState:
    def __init__(__self__, *,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 project: Optional[pulumi.Input[builtins.str]] = None,
                 project_id: Optional[pulumi.Input[builtins.int]] = None,
                 target_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]] = None,
                 target_project_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]] = None):
        """
        Input properties used for looking up and filtering ProjectJobTokenScopes resources.
        :param pulumi.Input[builtins.bool] enabled: Enable the given inbound allowlist. If false, will allow any project or group regardless of the values in `target_project_ids` or `target_group_ids`. Deleting the associated `ProjectJobTokenScopes` resource will reset `Enabled` on the group to `true`.
        :param pulumi.Input[builtins.str] project: The ID or full path of the project.
        :param pulumi.Input[builtins.int] project_id: The ID of the project.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.int]]] target_group_ids: A set of group IDs that are in the CI/CD job token inbound allowlist.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.int]]] target_project_ids: A set of project IDs that are in the CI/CD job token inbound allowlist.
        """
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if project_id is not None:
            warnings.warn("""`project_id` has been deprecated. Use `project` instead.""", DeprecationWarning)
            pulumi.log.warn("""project_id is deprecated: `project_id` has been deprecated. Use `project` instead.""")
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if target_group_ids is not None:
            pulumi.set(__self__, "target_group_ids", target_group_ids)
        if target_project_ids is not None:
            pulumi.set(__self__, "target_project_ids", target_project_ids)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Enable the given inbound allowlist. If false, will allow any project or group regardless of the values in `target_project_ids` or `target_group_ids`. Deleting the associated `ProjectJobTokenScopes` resource will reset `Enabled` on the group to `true`.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID or full path of the project.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter(name="projectId")
    @_utilities.deprecated("""`project_id` has been deprecated. Use `project` instead.""")
    def project_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The ID of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "project_id", value)

    @property
    @pulumi.getter(name="targetGroupIds")
    def target_group_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]]:
        """
        A set of group IDs that are in the CI/CD job token inbound allowlist.
        """
        return pulumi.get(self, "target_group_ids")

    @target_group_ids.setter
    def target_group_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]]):
        pulumi.set(self, "target_group_ids", value)

    @property
    @pulumi.getter(name="targetProjectIds")
    def target_project_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]]:
        """
        A set of project IDs that are in the CI/CD job token inbound allowlist.
        """
        return pulumi.get(self, "target_project_ids")

    @target_project_ids.setter
    def target_project_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]]):
        pulumi.set(self, "target_project_ids", value)


class ProjectJobTokenScopes(pulumi.CustomResource):

    pulumi_type = "gitlab:index/projectJobTokenScopes:ProjectJobTokenScopes"

    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 project: Optional[pulumi.Input[builtins.str]] = None,
                 project_id: Optional[pulumi.Input[builtins.int]] = None,
                 target_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]] = None,
                 target_project_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]] = None,
                 __props__=None):
        """
        The `ProjectJobTokenScopes` resource allows to manage the CI/CD Job Token scopes in a project.
        Any project or group not within the defined set of `target_project_ids` or `target_group_ids`, respectively, will be removed,
        which allows this resource to be used as an explicit deny.

        > Conflicts with the use of `ProjectJobTokenScope` when used on the same project. Use one or the other to ensure the desired state.

        > If the `enabled` property is false, any project or group will be allowed regardless of the given allowlist attributes.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/project_job_token_scopes/)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        allowed_single_project = gitlab.ProjectJobTokenScopes("allowed_single_project",
            project="111",
            target_project_ids=[123])
        allowed_multiple_project = gitlab.ProjectJobTokenScopes("allowed_multiple_project",
            project="111",
            target_project_ids=[
                123,
                456,
                789,
            ])
        allowed_multiple_groups = gitlab.ProjectJobTokenScopes("allowed_multiple_groups",
            project_id=111,
            target_project_ids=[],
            target_group_ids=[
                321,
                654,
            ])
        # This will remove all job token scopes, even if added outside of TF.
        explicit_deny = gitlab.ProjectJobTokenScopes("explicit_deny",
            project="111",
            target_project_ids=[])
        # This shows the explicit behavior of the enabled flag with a list of projects and groups.
        allow_projects_and_groups = gitlab.ProjectJobTokenScopes("allow_projects_and_groups",
            project="111",
            enabled=True,
            target_project_ids=[
                123,
                456,
                789,
            ],
            target_group_ids=[
                321,
                654,
            ])
        # This allows all projects and groups (disabling the CI Job Token scope protection)
        allow_all = gitlab.ProjectJobTokenScopes("allow_all",
            project="111",
            enabled=False)
        ```

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_project_job_token_scopes`. For example:

        terraform

        import {

          to = gitlab_project_job_token_scopes.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        GitLab project job token scopes can be imported using an id made up of just the `project_id`

        ```sh
        $ pulumi import gitlab:index/projectJobTokenScopes:ProjectJobTokenScopes bar 123
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] enabled: Enable the given inbound allowlist. If false, will allow any project or group regardless of the values in `target_project_ids` or `target_group_ids`. Deleting the associated `ProjectJobTokenScopes` resource will reset `Enabled` on the group to `true`.
        :param pulumi.Input[builtins.str] project: The ID or full path of the project.
        :param pulumi.Input[builtins.int] project_id: The ID of the project.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.int]]] target_group_ids: A set of group IDs that are in the CI/CD job token inbound allowlist.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.int]]] target_project_ids: A set of project IDs that are in the CI/CD job token inbound allowlist.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[ProjectJobTokenScopesArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `ProjectJobTokenScopes` resource allows to manage the CI/CD Job Token scopes in a project.
        Any project or group not within the defined set of `target_project_ids` or `target_group_ids`, respectively, will be removed,
        which allows this resource to be used as an explicit deny.

        > Conflicts with the use of `ProjectJobTokenScope` when used on the same project. Use one or the other to ensure the desired state.

        > If the `enabled` property is false, any project or group will be allowed regardless of the given allowlist attributes.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/project_job_token_scopes/)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        allowed_single_project = gitlab.ProjectJobTokenScopes("allowed_single_project",
            project="111",
            target_project_ids=[123])
        allowed_multiple_project = gitlab.ProjectJobTokenScopes("allowed_multiple_project",
            project="111",
            target_project_ids=[
                123,
                456,
                789,
            ])
        allowed_multiple_groups = gitlab.ProjectJobTokenScopes("allowed_multiple_groups",
            project_id=111,
            target_project_ids=[],
            target_group_ids=[
                321,
                654,
            ])
        # This will remove all job token scopes, even if added outside of TF.
        explicit_deny = gitlab.ProjectJobTokenScopes("explicit_deny",
            project="111",
            target_project_ids=[])
        # This shows the explicit behavior of the enabled flag with a list of projects and groups.
        allow_projects_and_groups = gitlab.ProjectJobTokenScopes("allow_projects_and_groups",
            project="111",
            enabled=True,
            target_project_ids=[
                123,
                456,
                789,
            ],
            target_group_ids=[
                321,
                654,
            ])
        # This allows all projects and groups (disabling the CI Job Token scope protection)
        allow_all = gitlab.ProjectJobTokenScopes("allow_all",
            project="111",
            enabled=False)
        ```

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_project_job_token_scopes`. For example:

        terraform

        import {

          to = gitlab_project_job_token_scopes.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        GitLab project job token scopes can be imported using an id made up of just the `project_id`

        ```sh
        $ pulumi import gitlab:index/projectJobTokenScopes:ProjectJobTokenScopes bar 123
        ```

        :param str resource_name: The name of the resource.
        :param ProjectJobTokenScopesArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProjectJobTokenScopesArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 project: Optional[pulumi.Input[builtins.str]] = None,
                 project_id: Optional[pulumi.Input[builtins.int]] = None,
                 target_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]] = None,
                 target_project_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProjectJobTokenScopesArgs.__new__(ProjectJobTokenScopesArgs)

            __props__.__dict__["enabled"] = enabled
            __props__.__dict__["project"] = project
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["target_group_ids"] = target_group_ids
            __props__.__dict__["target_project_ids"] = target_project_ids
        super(ProjectJobTokenScopes, __self__).__init__(
            'gitlab:index/projectJobTokenScopes:ProjectJobTokenScopes',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            enabled: Optional[pulumi.Input[builtins.bool]] = None,
            project: Optional[pulumi.Input[builtins.str]] = None,
            project_id: Optional[pulumi.Input[builtins.int]] = None,
            target_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]] = None,
            target_project_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]] = None) -> 'ProjectJobTokenScopes':
        """
        Get an existing ProjectJobTokenScopes resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] enabled: Enable the given inbound allowlist. If false, will allow any project or group regardless of the values in `target_project_ids` or `target_group_ids`. Deleting the associated `ProjectJobTokenScopes` resource will reset `Enabled` on the group to `true`.
        :param pulumi.Input[builtins.str] project: The ID or full path of the project.
        :param pulumi.Input[builtins.int] project_id: The ID of the project.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.int]]] target_group_ids: A set of group IDs that are in the CI/CD job token inbound allowlist.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.int]]] target_project_ids: A set of project IDs that are in the CI/CD job token inbound allowlist.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProjectJobTokenScopesState.__new__(_ProjectJobTokenScopesState)

        __props__.__dict__["enabled"] = enabled
        __props__.__dict__["project"] = project
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["target_group_ids"] = target_group_ids
        __props__.__dict__["target_project_ids"] = target_project_ids
        return ProjectJobTokenScopes(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[builtins.bool]:
        """
        Enable the given inbound allowlist. If false, will allow any project or group regardless of the values in `target_project_ids` or `target_group_ids`. Deleting the associated `ProjectJobTokenScopes` resource will reset `Enabled` on the group to `true`.
        """
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter
    def project(self) -> pulumi.Output[builtins.str]:
        """
        The ID or full path of the project.
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter(name="projectId")
    @_utilities.deprecated("""`project_id` has been deprecated. Use `project` instead.""")
    def project_id(self) -> pulumi.Output[builtins.int]:
        """
        The ID of the project.
        """
        return pulumi.get(self, "project_id")

    @property
    @pulumi.getter(name="targetGroupIds")
    def target_group_ids(self) -> pulumi.Output[Sequence[builtins.int]]:
        """
        A set of group IDs that are in the CI/CD job token inbound allowlist.
        """
        return pulumi.get(self, "target_group_ids")

    @property
    @pulumi.getter(name="targetProjectIds")
    def target_project_ids(self) -> pulumi.Output[Sequence[builtins.int]]:
        """
        A set of project IDs that are in the CI/CD job token inbound allowlist.
        """
        return pulumi.get(self, "target_project_ids")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetRepositoryFileResult',
    'AwaitableGetRepositoryFileResult',
    'get_repository_file',
    'get_repository_file_output',
]

@pulumi.output_type
class GetRepositoryFileResult:
    """
    A collection of values returned by getRepositoryFile.
    """
    def __init__(__self__, blob_id=None, commit_id=None, content=None, content_sha256=None, encoding=None, execute_filemode=None, file_name=None, file_path=None, id=None, last_commit_id=None, project=None, ref=None, size=None):
        if blob_id and not isinstance(blob_id, str):
            raise TypeError("Expected argument 'blob_id' to be a str")
        pulumi.set(__self__, "blob_id", blob_id)
        if commit_id and not isinstance(commit_id, str):
            raise TypeError("Expected argument 'commit_id' to be a str")
        pulumi.set(__self__, "commit_id", commit_id)
        if content and not isinstance(content, str):
            raise TypeError("Expected argument 'content' to be a str")
        pulumi.set(__self__, "content", content)
        if content_sha256 and not isinstance(content_sha256, str):
            raise TypeError("Expected argument 'content_sha256' to be a str")
        pulumi.set(__self__, "content_sha256", content_sha256)
        if encoding and not isinstance(encoding, str):
            raise TypeError("Expected argument 'encoding' to be a str")
        pulumi.set(__self__, "encoding", encoding)
        if execute_filemode and not isinstance(execute_filemode, bool):
            raise TypeError("Expected argument 'execute_filemode' to be a bool")
        pulumi.set(__self__, "execute_filemode", execute_filemode)
        if file_name and not isinstance(file_name, str):
            raise TypeError("Expected argument 'file_name' to be a str")
        pulumi.set(__self__, "file_name", file_name)
        if file_path and not isinstance(file_path, str):
            raise TypeError("Expected argument 'file_path' to be a str")
        pulumi.set(__self__, "file_path", file_path)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if last_commit_id and not isinstance(last_commit_id, str):
            raise TypeError("Expected argument 'last_commit_id' to be a str")
        pulumi.set(__self__, "last_commit_id", last_commit_id)
        if project and not isinstance(project, str):
            raise TypeError("Expected argument 'project' to be a str")
        pulumi.set(__self__, "project", project)
        if ref and not isinstance(ref, str):
            raise TypeError("Expected argument 'ref' to be a str")
        pulumi.set(__self__, "ref", ref)
        if size and not isinstance(size, int):
            raise TypeError("Expected argument 'size' to be a int")
        pulumi.set(__self__, "size", size)

    @property
    @pulumi.getter(name="blobId")
    def blob_id(self) -> builtins.str:
        """
        The blob id.
        """
        return pulumi.get(self, "blob_id")

    @property
    @pulumi.getter(name="commitId")
    def commit_id(self) -> builtins.str:
        """
        The commit id.
        """
        return pulumi.get(self, "commit_id")

    @property
    @pulumi.getter
    def content(self) -> builtins.str:
        """
        File content.
        """
        return pulumi.get(self, "content")

    @property
    @pulumi.getter(name="contentSha256")
    def content_sha256(self) -> builtins.str:
        """
        File content sha256 digest.
        """
        return pulumi.get(self, "content_sha256")

    @property
    @pulumi.getter
    def encoding(self) -> builtins.str:
        """
        The file content encoding.
        """
        return pulumi.get(self, "encoding")

    @property
    @pulumi.getter(name="executeFilemode")
    def execute_filemode(self) -> builtins.bool:
        """
        Enables or disables the execute flag on the file.
        """
        return pulumi.get(self, "execute_filemode")

    @property
    @pulumi.getter(name="fileName")
    def file_name(self) -> builtins.str:
        """
        The filename.
        """
        return pulumi.get(self, "file_name")

    @property
    @pulumi.getter(name="filePath")
    def file_path(self) -> builtins.str:
        """
        The full path of the file. It must be relative to the root of the project without a leading slash `/` or `./`.
        """
        return pulumi.get(self, "file_path")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="lastCommitId")
    def last_commit_id(self) -> builtins.str:
        """
        The last known commit id.
        """
        return pulumi.get(self, "last_commit_id")

    @property
    @pulumi.getter
    def project(self) -> builtins.str:
        """
        The name or ID of the project.
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter
    def ref(self) -> builtins.str:
        """
        The name of branch, tag or commit.
        """
        return pulumi.get(self, "ref")

    @property
    @pulumi.getter
    def size(self) -> builtins.int:
        """
        The file size.
        """
        return pulumi.get(self, "size")


class AwaitableGetRepositoryFileResult(GetRepositoryFileResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRepositoryFileResult(
            blob_id=self.blob_id,
            commit_id=self.commit_id,
            content=self.content,
            content_sha256=self.content_sha256,
            encoding=self.encoding,
            execute_filemode=self.execute_filemode,
            file_name=self.file_name,
            file_path=self.file_path,
            id=self.id,
            last_commit_id=self.last_commit_id,
            project=self.project,
            ref=self.ref,
            size=self.size)


def get_repository_file(file_path: Optional[builtins.str] = None,
                        project: Optional[builtins.str] = None,
                        ref: Optional[builtins.str] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRepositoryFileResult:
    """
    The `RepositoryFile` data source allows details of a file in a repository to be retrieved.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/repository_files/)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    example = gitlab.get_repository_file(project="example",
        ref="main",
        file_path="README.md")
    ```


    :param builtins.str file_path: The full path of the file. It must be relative to the root of the project without a leading slash `/` or `./`.
    :param builtins.str project: The name or ID of the project.
    :param builtins.str ref: The name of branch, tag or commit.
    """
    __args__ = dict()
    __args__['filePath'] = file_path
    __args__['project'] = project
    __args__['ref'] = ref
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('gitlab:index/getRepositoryFile:getRepositoryFile', __args__, opts=opts, typ=GetRepositoryFileResult).value

    return AwaitableGetRepositoryFileResult(
        blob_id=pulumi.get(__ret__, 'blob_id'),
        commit_id=pulumi.get(__ret__, 'commit_id'),
        content=pulumi.get(__ret__, 'content'),
        content_sha256=pulumi.get(__ret__, 'content_sha256'),
        encoding=pulumi.get(__ret__, 'encoding'),
        execute_filemode=pulumi.get(__ret__, 'execute_filemode'),
        file_name=pulumi.get(__ret__, 'file_name'),
        file_path=pulumi.get(__ret__, 'file_path'),
        id=pulumi.get(__ret__, 'id'),
        last_commit_id=pulumi.get(__ret__, 'last_commit_id'),
        project=pulumi.get(__ret__, 'project'),
        ref=pulumi.get(__ret__, 'ref'),
        size=pulumi.get(__ret__, 'size'))
def get_repository_file_output(file_path: Optional[pulumi.Input[builtins.str]] = None,
                               project: Optional[pulumi.Input[builtins.str]] = None,
                               ref: Optional[pulumi.Input[builtins.str]] = None,
                               opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetRepositoryFileResult]:
    """
    The `RepositoryFile` data source allows details of a file in a repository to be retrieved.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/repository_files/)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    example = gitlab.get_repository_file(project="example",
        ref="main",
        file_path="README.md")
    ```


    :param builtins.str file_path: The full path of the file. It must be relative to the root of the project without a leading slash `/` or `./`.
    :param builtins.str project: The name or ID of the project.
    :param builtins.str ref: The name of branch, tag or commit.
    """
    __args__ = dict()
    __args__['filePath'] = file_path
    __args__['project'] = project
    __args__['ref'] = ref
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('gitlab:index/getRepositoryFile:getRepositoryFile', __args__, opts=opts, typ=GetRepositoryFileResult)
    return __ret__.apply(lambda __response__: GetRepositoryFileResult(
        blob_id=pulumi.get(__response__, 'blob_id'),
        commit_id=pulumi.get(__response__, 'commit_id'),
        content=pulumi.get(__response__, 'content'),
        content_sha256=pulumi.get(__response__, 'content_sha256'),
        encoding=pulumi.get(__response__, 'encoding'),
        execute_filemode=pulumi.get(__response__, 'execute_filemode'),
        file_name=pulumi.get(__response__, 'file_name'),
        file_path=pulumi.get(__response__, 'file_path'),
        id=pulumi.get(__response__, 'id'),
        last_commit_id=pulumi.get(__response__, 'last_commit_id'),
        project=pulumi.get(__response__, 'project'),
        ref=pulumi.get(__response__, 'ref'),
        size=pulumi.get(__response__, 'size')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ProjectCustomAttributeArgs', 'ProjectCustomAttribute']

@pulumi.input_type
class ProjectCustomAttributeArgs:
    def __init__(__self__, *,
                 key: pulumi.Input[builtins.str],
                 project: pulumi.Input[builtins.int],
                 value: pulumi.Input[builtins.str]):
        """
        The set of arguments for constructing a ProjectCustomAttribute resource.
        :param pulumi.Input[builtins.str] key: Key for the Custom Attribute.
        :param pulumi.Input[builtins.int] project: The id of the project.
        :param pulumi.Input[builtins.str] value: Value for the Custom Attribute.
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "project", project)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> pulumi.Input[builtins.str]:
        """
        Key for the Custom Attribute.
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def project(self) -> pulumi.Input[builtins.int]:
        """
        The id of the project.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter
    def value(self) -> pulumi.Input[builtins.str]:
        """
        Value for the Custom Attribute.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "value", value)


@pulumi.input_type
class _ProjectCustomAttributeState:
    def __init__(__self__, *,
                 key: Optional[pulumi.Input[builtins.str]] = None,
                 project: Optional[pulumi.Input[builtins.int]] = None,
                 value: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering ProjectCustomAttribute resources.
        :param pulumi.Input[builtins.str] key: Key for the Custom Attribute.
        :param pulumi.Input[builtins.int] project: The id of the project.
        :param pulumi.Input[builtins.str] value: Value for the Custom Attribute.
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Key for the Custom Attribute.
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The id of the project.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Value for the Custom Attribute.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "value", value)


class ProjectCustomAttribute(pulumi.CustomResource):

    pulumi_type = "gitlab:index/projectCustomAttribute:ProjectCustomAttribute"

    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 key: Optional[pulumi.Input[builtins.str]] = None,
                 project: Optional[pulumi.Input[builtins.int]] = None,
                 value: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        The `ProjectCustomAttribute` resource allows to manage custom attributes for a project.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/custom_attributes/)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        attr = gitlab.ProjectCustomAttribute("attr",
            project=42,
            key="location",
            value="Greenland")
        ```

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_project_custom_attribute`. For example:

        terraform

        import {

          to = gitlab_project_custom_attribute.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        You can import a project custom attribute using an id made up of `{project-id}:{key}`, e.g.

        ```sh
        $ pulumi import gitlab:index/projectCustomAttribute:ProjectCustomAttribute attr 42:location
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] key: Key for the Custom Attribute.
        :param pulumi.Input[builtins.int] project: The id of the project.
        :param pulumi.Input[builtins.str] value: Value for the Custom Attribute.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProjectCustomAttributeArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `ProjectCustomAttribute` resource allows to manage custom attributes for a project.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/custom_attributes/)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        attr = gitlab.ProjectCustomAttribute("attr",
            project=42,
            key="location",
            value="Greenland")
        ```

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_project_custom_attribute`. For example:

        terraform

        import {

          to = gitlab_project_custom_attribute.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        You can import a project custom attribute using an id made up of `{project-id}:{key}`, e.g.

        ```sh
        $ pulumi import gitlab:index/projectCustomAttribute:ProjectCustomAttribute attr 42:location
        ```

        :param str resource_name: The name of the resource.
        :param ProjectCustomAttributeArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProjectCustomAttributeArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 key: Optional[pulumi.Input[builtins.str]] = None,
                 project: Optional[pulumi.Input[builtins.int]] = None,
                 value: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProjectCustomAttributeArgs.__new__(ProjectCustomAttributeArgs)

            if key is None and not opts.urn:
                raise TypeError("Missing required property 'key'")
            __props__.__dict__["key"] = key
            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
            if value is None and not opts.urn:
                raise TypeError("Missing required property 'value'")
            __props__.__dict__["value"] = value
        super(ProjectCustomAttribute, __self__).__init__(
            'gitlab:index/projectCustomAttribute:ProjectCustomAttribute',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            key: Optional[pulumi.Input[builtins.str]] = None,
            project: Optional[pulumi.Input[builtins.int]] = None,
            value: Optional[pulumi.Input[builtins.str]] = None) -> 'ProjectCustomAttribute':
        """
        Get an existing ProjectCustomAttribute resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] key: Key for the Custom Attribute.
        :param pulumi.Input[builtins.int] project: The id of the project.
        :param pulumi.Input[builtins.str] value: Value for the Custom Attribute.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProjectCustomAttributeState.__new__(_ProjectCustomAttributeState)

        __props__.__dict__["key"] = key
        __props__.__dict__["project"] = project
        __props__.__dict__["value"] = value
        return ProjectCustomAttribute(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def key(self) -> pulumi.Output[builtins.str]:
        """
        Key for the Custom Attribute.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def project(self) -> pulumi.Output[builtins.int]:
        """
        The id of the project.
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter
    def value(self) -> pulumi.Output[builtins.str]:
        """
        Value for the Custom Attribute.
        """
        return pulumi.get(self, "value")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['GroupShareGroupArgs', 'GroupShareGroup']

@pulumi.input_type
class GroupShareGroupArgs:
    def __init__(__self__, *,
                 group_access: pulumi.Input[builtins.str],
                 group_id: pulumi.Input[builtins.str],
                 share_group_id: pulumi.Input[builtins.int],
                 expires_at: Optional[pulumi.Input[builtins.str]] = None,
                 member_role_id: Optional[pulumi.Input[builtins.int]] = None):
        """
        The set of arguments for constructing a GroupShareGroup resource.
        :param pulumi.Input[builtins.str] group_access: The access level to grant the group. Valid values are: `no one`, `minimal`, `guest`, `planner`, `reporter`, `developer`, `maintainer`, `owner`
        :param pulumi.Input[builtins.str] group_id: The id of the main group to be shared.
        :param pulumi.Input[builtins.int] share_group_id: The id of the additional group with which the main group will be shared.
        :param pulumi.Input[builtins.str] expires_at: Share expiration date. Format: `YYYY-MM-DD`
        :param pulumi.Input[builtins.int] member_role_id: The ID of a custom member role. Only available for Ultimate instances.
        """
        pulumi.set(__self__, "group_access", group_access)
        pulumi.set(__self__, "group_id", group_id)
        pulumi.set(__self__, "share_group_id", share_group_id)
        if expires_at is not None:
            pulumi.set(__self__, "expires_at", expires_at)
        if member_role_id is not None:
            pulumi.set(__self__, "member_role_id", member_role_id)

    @property
    @pulumi.getter(name="groupAccess")
    def group_access(self) -> pulumi.Input[builtins.str]:
        """
        The access level to grant the group. Valid values are: `no one`, `minimal`, `guest`, `planner`, `reporter`, `developer`, `maintainer`, `owner`
        """
        return pulumi.get(self, "group_access")

    @group_access.setter
    def group_access(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "group_access", value)

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> pulumi.Input[builtins.str]:
        """
        The id of the main group to be shared.
        """
        return pulumi.get(self, "group_id")

    @group_id.setter
    def group_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "group_id", value)

    @property
    @pulumi.getter(name="shareGroupId")
    def share_group_id(self) -> pulumi.Input[builtins.int]:
        """
        The id of the additional group with which the main group will be shared.
        """
        return pulumi.get(self, "share_group_id")

    @share_group_id.setter
    def share_group_id(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "share_group_id", value)

    @property
    @pulumi.getter(name="expiresAt")
    def expires_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Share expiration date. Format: `YYYY-MM-DD`
        """
        return pulumi.get(self, "expires_at")

    @expires_at.setter
    def expires_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "expires_at", value)

    @property
    @pulumi.getter(name="memberRoleId")
    def member_role_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The ID of a custom member role. Only available for Ultimate instances.
        """
        return pulumi.get(self, "member_role_id")

    @member_role_id.setter
    def member_role_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "member_role_id", value)


@pulumi.input_type
class _GroupShareGroupState:
    def __init__(__self__, *,
                 expires_at: Optional[pulumi.Input[builtins.str]] = None,
                 group_access: Optional[pulumi.Input[builtins.str]] = None,
                 group_id: Optional[pulumi.Input[builtins.str]] = None,
                 member_role_id: Optional[pulumi.Input[builtins.int]] = None,
                 share_group_id: Optional[pulumi.Input[builtins.int]] = None):
        """
        Input properties used for looking up and filtering GroupShareGroup resources.
        :param pulumi.Input[builtins.str] expires_at: Share expiration date. Format: `YYYY-MM-DD`
        :param pulumi.Input[builtins.str] group_access: The access level to grant the group. Valid values are: `no one`, `minimal`, `guest`, `planner`, `reporter`, `developer`, `maintainer`, `owner`
        :param pulumi.Input[builtins.str] group_id: The id of the main group to be shared.
        :param pulumi.Input[builtins.int] member_role_id: The ID of a custom member role. Only available for Ultimate instances.
        :param pulumi.Input[builtins.int] share_group_id: The id of the additional group with which the main group will be shared.
        """
        if expires_at is not None:
            pulumi.set(__self__, "expires_at", expires_at)
        if group_access is not None:
            pulumi.set(__self__, "group_access", group_access)
        if group_id is not None:
            pulumi.set(__self__, "group_id", group_id)
        if member_role_id is not None:
            pulumi.set(__self__, "member_role_id", member_role_id)
        if share_group_id is not None:
            pulumi.set(__self__, "share_group_id", share_group_id)

    @property
    @pulumi.getter(name="expiresAt")
    def expires_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Share expiration date. Format: `YYYY-MM-DD`
        """
        return pulumi.get(self, "expires_at")

    @expires_at.setter
    def expires_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "expires_at", value)

    @property
    @pulumi.getter(name="groupAccess")
    def group_access(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The access level to grant the group. Valid values are: `no one`, `minimal`, `guest`, `planner`, `reporter`, `developer`, `maintainer`, `owner`
        """
        return pulumi.get(self, "group_access")

    @group_access.setter
    def group_access(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "group_access", value)

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The id of the main group to be shared.
        """
        return pulumi.get(self, "group_id")

    @group_id.setter
    def group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "group_id", value)

    @property
    @pulumi.getter(name="memberRoleId")
    def member_role_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The ID of a custom member role. Only available for Ultimate instances.
        """
        return pulumi.get(self, "member_role_id")

    @member_role_id.setter
    def member_role_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "member_role_id", value)

    @property
    @pulumi.getter(name="shareGroupId")
    def share_group_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The id of the additional group with which the main group will be shared.
        """
        return pulumi.get(self, "share_group_id")

    @share_group_id.setter
    def share_group_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "share_group_id", value)


class GroupShareGroup(pulumi.CustomResource):

    pulumi_type = "gitlab:index/groupShareGroup:GroupShareGroup"

    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 expires_at: Optional[pulumi.Input[builtins.str]] = None,
                 group_access: Optional[pulumi.Input[builtins.str]] = None,
                 group_id: Optional[pulumi.Input[builtins.str]] = None,
                 member_role_id: Optional[pulumi.Input[builtins.int]] = None,
                 share_group_id: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        """
        The `GroupShareGroup` resource allows managing the lifecycle of a group shared with another group.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/groups/#share-groups-with-groups)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        test = gitlab.GroupShareGroup("test",
            group_id=foo["id"],
            share_group_id=bar["id"],
            group_access="guest",
            expires_at="2099-01-01")
        ```

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_group_share_group`. For example:

        terraform

        import {

          to = gitlab_group_share_group.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        GitLab group shares can be imported using an id made up of `mainGroupId:shareGroupId`, e.g.

        ```sh
        $ pulumi import gitlab:index/groupShareGroup:GroupShareGroup test 12345:1337
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] expires_at: Share expiration date. Format: `YYYY-MM-DD`
        :param pulumi.Input[builtins.str] group_access: The access level to grant the group. Valid values are: `no one`, `minimal`, `guest`, `planner`, `reporter`, `developer`, `maintainer`, `owner`
        :param pulumi.Input[builtins.str] group_id: The id of the main group to be shared.
        :param pulumi.Input[builtins.int] member_role_id: The ID of a custom member role. Only available for Ultimate instances.
        :param pulumi.Input[builtins.int] share_group_id: The id of the additional group with which the main group will be shared.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GroupShareGroupArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `GroupShareGroup` resource allows managing the lifecycle of a group shared with another group.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/groups/#share-groups-with-groups)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        test = gitlab.GroupShareGroup("test",
            group_id=foo["id"],
            share_group_id=bar["id"],
            group_access="guest",
            expires_at="2099-01-01")
        ```

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_group_share_group`. For example:

        terraform

        import {

          to = gitlab_group_share_group.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        GitLab group shares can be imported using an id made up of `mainGroupId:shareGroupId`, e.g.

        ```sh
        $ pulumi import gitlab:index/groupShareGroup:GroupShareGroup test 12345:1337
        ```

        :param str resource_name: The name of the resource.
        :param GroupShareGroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GroupShareGroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 expires_at: Optional[pulumi.Input[builtins.str]] = None,
                 group_access: Optional[pulumi.Input[builtins.str]] = None,
                 group_id: Optional[pulumi.Input[builtins.str]] = None,
                 member_role_id: Optional[pulumi.Input[builtins.int]] = None,
                 share_group_id: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GroupShareGroupArgs.__new__(GroupShareGroupArgs)

            __props__.__dict__["expires_at"] = expires_at
            if group_access is None and not opts.urn:
                raise TypeError("Missing required property 'group_access'")
            __props__.__dict__["group_access"] = group_access
            if group_id is None and not opts.urn:
                raise TypeError("Missing required property 'group_id'")
            __props__.__dict__["group_id"] = group_id
            __props__.__dict__["member_role_id"] = member_role_id
            if share_group_id is None and not opts.urn:
                raise TypeError("Missing required property 'share_group_id'")
            __props__.__dict__["share_group_id"] = share_group_id
        super(GroupShareGroup, __self__).__init__(
            'gitlab:index/groupShareGroup:GroupShareGroup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            expires_at: Optional[pulumi.Input[builtins.str]] = None,
            group_access: Optional[pulumi.Input[builtins.str]] = None,
            group_id: Optional[pulumi.Input[builtins.str]] = None,
            member_role_id: Optional[pulumi.Input[builtins.int]] = None,
            share_group_id: Optional[pulumi.Input[builtins.int]] = None) -> 'GroupShareGroup':
        """
        Get an existing GroupShareGroup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] expires_at: Share expiration date. Format: `YYYY-MM-DD`
        :param pulumi.Input[builtins.str] group_access: The access level to grant the group. Valid values are: `no one`, `minimal`, `guest`, `planner`, `reporter`, `developer`, `maintainer`, `owner`
        :param pulumi.Input[builtins.str] group_id: The id of the main group to be shared.
        :param pulumi.Input[builtins.int] member_role_id: The ID of a custom member role. Only available for Ultimate instances.
        :param pulumi.Input[builtins.int] share_group_id: The id of the additional group with which the main group will be shared.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GroupShareGroupState.__new__(_GroupShareGroupState)

        __props__.__dict__["expires_at"] = expires_at
        __props__.__dict__["group_access"] = group_access
        __props__.__dict__["group_id"] = group_id
        __props__.__dict__["member_role_id"] = member_role_id
        __props__.__dict__["share_group_id"] = share_group_id
        return GroupShareGroup(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="expiresAt")
    def expires_at(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Share expiration date. Format: `YYYY-MM-DD`
        """
        return pulumi.get(self, "expires_at")

    @property
    @pulumi.getter(name="groupAccess")
    def group_access(self) -> pulumi.Output[builtins.str]:
        """
        The access level to grant the group. Valid values are: `no one`, `minimal`, `guest`, `planner`, `reporter`, `developer`, `maintainer`, `owner`
        """
        return pulumi.get(self, "group_access")

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> pulumi.Output[builtins.str]:
        """
        The id of the main group to be shared.
        """
        return pulumi.get(self, "group_id")

    @property
    @pulumi.getter(name="memberRoleId")
    def member_role_id(self) -> pulumi.Output[builtins.int]:
        """
        The ID of a custom member role. Only available for Ultimate instances.
        """
        return pulumi.get(self, "member_role_id")

    @property
    @pulumi.getter(name="shareGroupId")
    def share_group_id(self) -> pulumi.Output[builtins.int]:
        """
        The id of the additional group with which the main group will be shared.
        """
        return pulumi.get(self, "share_group_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['IntegrationSlackArgs', 'IntegrationSlack']

@pulumi.input_type
class IntegrationSlackArgs:
    def __init__(__self__, *,
                 project: pulumi.Input[builtins.str],
                 webhook: pulumi.Input[builtins.str],
                 branches_to_be_notified: Optional[pulumi.Input[builtins.str]] = None,
                 confidential_issue_channel: Optional[pulumi.Input[builtins.str]] = None,
                 confidential_issues_events: Optional[pulumi.Input[builtins.bool]] = None,
                 confidential_note_channel: Optional[pulumi.Input[builtins.str]] = None,
                 confidential_note_events: Optional[pulumi.Input[builtins.bool]] = None,
                 issue_channel: Optional[pulumi.Input[builtins.str]] = None,
                 issues_events: Optional[pulumi.Input[builtins.bool]] = None,
                 merge_request_channel: Optional[pulumi.Input[builtins.str]] = None,
                 merge_requests_events: Optional[pulumi.Input[builtins.bool]] = None,
                 note_channel: Optional[pulumi.Input[builtins.str]] = None,
                 note_events: Optional[pulumi.Input[builtins.bool]] = None,
                 notify_only_broken_pipelines: Optional[pulumi.Input[builtins.bool]] = None,
                 notify_only_default_branch: Optional[pulumi.Input[builtins.bool]] = None,
                 pipeline_channel: Optional[pulumi.Input[builtins.str]] = None,
                 pipeline_events: Optional[pulumi.Input[builtins.bool]] = None,
                 push_channel: Optional[pulumi.Input[builtins.str]] = None,
                 push_events: Optional[pulumi.Input[builtins.bool]] = None,
                 tag_push_channel: Optional[pulumi.Input[builtins.str]] = None,
                 tag_push_events: Optional[pulumi.Input[builtins.bool]] = None,
                 username: Optional[pulumi.Input[builtins.str]] = None,
                 wiki_page_channel: Optional[pulumi.Input[builtins.str]] = None,
                 wiki_page_events: Optional[pulumi.Input[builtins.bool]] = None):
        """
        The set of arguments for constructing a IntegrationSlack resource.
        :param pulumi.Input[builtins.str] project: ID of the project you want to activate integration on.
        :param pulumi.Input[builtins.str] webhook: Webhook URL (Example, https://hooks.slack.com/services/...). This value cannot be imported.
        :param pulumi.Input[builtins.str] branches_to_be_notified: Branches to send notifications for. Valid options are "all", "default", "protected", and "default*and*protected".
        :param pulumi.Input[builtins.str] confidential_issue_channel: The name of the channel to receive confidential issue events notifications.
        :param pulumi.Input[builtins.bool] confidential_issues_events: Enable notifications for confidential issues events.
        :param pulumi.Input[builtins.str] confidential_note_channel: The name of the channel to receive confidential note events notifications.
        :param pulumi.Input[builtins.bool] confidential_note_events: Enable notifications for confidential note events.
        :param pulumi.Input[builtins.str] issue_channel: The name of the channel to receive issue events notifications.
        :param pulumi.Input[builtins.bool] issues_events: Enable notifications for issues events.
        :param pulumi.Input[builtins.str] merge_request_channel: The name of the channel to receive merge request events notifications.
        :param pulumi.Input[builtins.bool] merge_requests_events: Enable notifications for merge requests events.
        :param pulumi.Input[builtins.str] note_channel: The name of the channel to receive note events notifications.
        :param pulumi.Input[builtins.bool] note_events: Enable notifications for note events.
        :param pulumi.Input[builtins.bool] notify_only_broken_pipelines: Send notifications for broken pipelines.
        :param pulumi.Input[builtins.bool] notify_only_default_branch: This parameter has been replaced with `branches_to_be_notified`.
        :param pulumi.Input[builtins.str] pipeline_channel: The name of the channel to receive pipeline events notifications.
        :param pulumi.Input[builtins.bool] pipeline_events: Enable notifications for pipeline events.
        :param pulumi.Input[builtins.str] push_channel: The name of the channel to receive push events notifications.
        :param pulumi.Input[builtins.bool] push_events: Enable notifications for push events.
        :param pulumi.Input[builtins.str] tag_push_channel: The name of the channel to receive tag push events notifications.
        :param pulumi.Input[builtins.bool] tag_push_events: Enable notifications for tag push events.
        :param pulumi.Input[builtins.str] username: Username to use.
        :param pulumi.Input[builtins.str] wiki_page_channel: The name of the channel to receive wiki page events notifications.
        :param pulumi.Input[builtins.bool] wiki_page_events: Enable notifications for wiki page events.
        """
        pulumi.set(__self__, "project", project)
        pulumi.set(__self__, "webhook", webhook)
        if branches_to_be_notified is not None:
            pulumi.set(__self__, "branches_to_be_notified", branches_to_be_notified)
        if confidential_issue_channel is not None:
            pulumi.set(__self__, "confidential_issue_channel", confidential_issue_channel)
        if confidential_issues_events is not None:
            pulumi.set(__self__, "confidential_issues_events", confidential_issues_events)
        if confidential_note_channel is not None:
            pulumi.set(__self__, "confidential_note_channel", confidential_note_channel)
        if confidential_note_events is not None:
            pulumi.set(__self__, "confidential_note_events", confidential_note_events)
        if issue_channel is not None:
            pulumi.set(__self__, "issue_channel", issue_channel)
        if issues_events is not None:
            pulumi.set(__self__, "issues_events", issues_events)
        if merge_request_channel is not None:
            pulumi.set(__self__, "merge_request_channel", merge_request_channel)
        if merge_requests_events is not None:
            pulumi.set(__self__, "merge_requests_events", merge_requests_events)
        if note_channel is not None:
            pulumi.set(__self__, "note_channel", note_channel)
        if note_events is not None:
            pulumi.set(__self__, "note_events", note_events)
        if notify_only_broken_pipelines is not None:
            pulumi.set(__self__, "notify_only_broken_pipelines", notify_only_broken_pipelines)
        if notify_only_default_branch is not None:
            warnings.warn("""use 'branches_to_be_notified' argument instead""", DeprecationWarning)
            pulumi.log.warn("""notify_only_default_branch is deprecated: use 'branches_to_be_notified' argument instead""")
        if notify_only_default_branch is not None:
            pulumi.set(__self__, "notify_only_default_branch", notify_only_default_branch)
        if pipeline_channel is not None:
            pulumi.set(__self__, "pipeline_channel", pipeline_channel)
        if pipeline_events is not None:
            pulumi.set(__self__, "pipeline_events", pipeline_events)
        if push_channel is not None:
            pulumi.set(__self__, "push_channel", push_channel)
        if push_events is not None:
            pulumi.set(__self__, "push_events", push_events)
        if tag_push_channel is not None:
            pulumi.set(__self__, "tag_push_channel", tag_push_channel)
        if tag_push_events is not None:
            pulumi.set(__self__, "tag_push_events", tag_push_events)
        if username is not None:
            pulumi.set(__self__, "username", username)
        if wiki_page_channel is not None:
            pulumi.set(__self__, "wiki_page_channel", wiki_page_channel)
        if wiki_page_events is not None:
            pulumi.set(__self__, "wiki_page_events", wiki_page_events)

    @property
    @pulumi.getter
    def project(self) -> pulumi.Input[builtins.str]:
        """
        ID of the project you want to activate integration on.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter
    def webhook(self) -> pulumi.Input[builtins.str]:
        """
        Webhook URL (Example, https://hooks.slack.com/services/...). This value cannot be imported.
        """
        return pulumi.get(self, "webhook")

    @webhook.setter
    def webhook(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "webhook", value)

    @property
    @pulumi.getter(name="branchesToBeNotified")
    def branches_to_be_notified(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Branches to send notifications for. Valid options are "all", "default", "protected", and "default*and*protected".
        """
        return pulumi.get(self, "branches_to_be_notified")

    @branches_to_be_notified.setter
    def branches_to_be_notified(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "branches_to_be_notified", value)

    @property
    @pulumi.getter(name="confidentialIssueChannel")
    def confidential_issue_channel(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the channel to receive confidential issue events notifications.
        """
        return pulumi.get(self, "confidential_issue_channel")

    @confidential_issue_channel.setter
    def confidential_issue_channel(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "confidential_issue_channel", value)

    @property
    @pulumi.getter(name="confidentialIssuesEvents")
    def confidential_issues_events(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Enable notifications for confidential issues events.
        """
        return pulumi.get(self, "confidential_issues_events")

    @confidential_issues_events.setter
    def confidential_issues_events(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "confidential_issues_events", value)

    @property
    @pulumi.getter(name="confidentialNoteChannel")
    def confidential_note_channel(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the channel to receive confidential note events notifications.
        """
        return pulumi.get(self, "confidential_note_channel")

    @confidential_note_channel.setter
    def confidential_note_channel(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "confidential_note_channel", value)

    @property
    @pulumi.getter(name="confidentialNoteEvents")
    def confidential_note_events(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Enable notifications for confidential note events.
        """
        return pulumi.get(self, "confidential_note_events")

    @confidential_note_events.setter
    def confidential_note_events(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "confidential_note_events", value)

    @property
    @pulumi.getter(name="issueChannel")
    def issue_channel(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the channel to receive issue events notifications.
        """
        return pulumi.get(self, "issue_channel")

    @issue_channel.setter
    def issue_channel(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "issue_channel", value)

    @property
    @pulumi.getter(name="issuesEvents")
    def issues_events(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Enable notifications for issues events.
        """
        return pulumi.get(self, "issues_events")

    @issues_events.setter
    def issues_events(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "issues_events", value)

    @property
    @pulumi.getter(name="mergeRequestChannel")
    def merge_request_channel(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the channel to receive merge request events notifications.
        """
        return pulumi.get(self, "merge_request_channel")

    @merge_request_channel.setter
    def merge_request_channel(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "merge_request_channel", value)

    @property
    @pulumi.getter(name="mergeRequestsEvents")
    def merge_requests_events(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Enable notifications for merge requests events.
        """
        return pulumi.get(self, "merge_requests_events")

    @merge_requests_events.setter
    def merge_requests_events(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "merge_requests_events", value)

    @property
    @pulumi.getter(name="noteChannel")
    def note_channel(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the channel to receive note events notifications.
        """
        return pulumi.get(self, "note_channel")

    @note_channel.setter
    def note_channel(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "note_channel", value)

    @property
    @pulumi.getter(name="noteEvents")
    def note_events(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Enable notifications for note events.
        """
        return pulumi.get(self, "note_events")

    @note_events.setter
    def note_events(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "note_events", value)

    @property
    @pulumi.getter(name="notifyOnlyBrokenPipelines")
    def notify_only_broken_pipelines(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Send notifications for broken pipelines.
        """
        return pulumi.get(self, "notify_only_broken_pipelines")

    @notify_only_broken_pipelines.setter
    def notify_only_broken_pipelines(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "notify_only_broken_pipelines", value)

    @property
    @pulumi.getter(name="notifyOnlyDefaultBranch")
    @_utilities.deprecated("""use 'branches_to_be_notified' argument instead""")
    def notify_only_default_branch(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        This parameter has been replaced with `branches_to_be_notified`.
        """
        return pulumi.get(self, "notify_only_default_branch")

    @notify_only_default_branch.setter
    def notify_only_default_branch(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "notify_only_default_branch", value)

    @property
    @pulumi.getter(name="pipelineChannel")
    def pipeline_channel(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the channel to receive pipeline events notifications.
        """
        return pulumi.get(self, "pipeline_channel")

    @pipeline_channel.setter
    def pipeline_channel(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "pipeline_channel", value)

    @property
    @pulumi.getter(name="pipelineEvents")
    def pipeline_events(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Enable notifications for pipeline events.
        """
        return pulumi.get(self, "pipeline_events")

    @pipeline_events.setter
    def pipeline_events(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "pipeline_events", value)

    @property
    @pulumi.getter(name="pushChannel")
    def push_channel(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the channel to receive push events notifications.
        """
        return pulumi.get(self, "push_channel")

    @push_channel.setter
    def push_channel(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "push_channel", value)

    @property
    @pulumi.getter(name="pushEvents")
    def push_events(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Enable notifications for push events.
        """
        return pulumi.get(self, "push_events")

    @push_events.setter
    def push_events(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "push_events", value)

    @property
    @pulumi.getter(name="tagPushChannel")
    def tag_push_channel(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the channel to receive tag push events notifications.
        """
        return pulumi.get(self, "tag_push_channel")

    @tag_push_channel.setter
    def tag_push_channel(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "tag_push_channel", value)

    @property
    @pulumi.getter(name="tagPushEvents")
    def tag_push_events(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Enable notifications for tag push events.
        """
        return pulumi.get(self, "tag_push_events")

    @tag_push_events.setter
    def tag_push_events(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "tag_push_events", value)

    @property
    @pulumi.getter
    def username(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Username to use.
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "username", value)

    @property
    @pulumi.getter(name="wikiPageChannel")
    def wiki_page_channel(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the channel to receive wiki page events notifications.
        """
        return pulumi.get(self, "wiki_page_channel")

    @wiki_page_channel.setter
    def wiki_page_channel(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "wiki_page_channel", value)

    @property
    @pulumi.getter(name="wikiPageEvents")
    def wiki_page_events(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Enable notifications for wiki page events.
        """
        return pulumi.get(self, "wiki_page_events")

    @wiki_page_events.setter
    def wiki_page_events(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "wiki_page_events", value)


@pulumi.input_type
class _IntegrationSlackState:
    def __init__(__self__, *,
                 branches_to_be_notified: Optional[pulumi.Input[builtins.str]] = None,
                 confidential_issue_channel: Optional[pulumi.Input[builtins.str]] = None,
                 confidential_issues_events: Optional[pulumi.Input[builtins.bool]] = None,
                 confidential_note_channel: Optional[pulumi.Input[builtins.str]] = None,
                 confidential_note_events: Optional[pulumi.Input[builtins.bool]] = None,
                 issue_channel: Optional[pulumi.Input[builtins.str]] = None,
                 issues_events: Optional[pulumi.Input[builtins.bool]] = None,
                 job_events: Optional[pulumi.Input[builtins.bool]] = None,
                 merge_request_channel: Optional[pulumi.Input[builtins.str]] = None,
                 merge_requests_events: Optional[pulumi.Input[builtins.bool]] = None,
                 note_channel: Optional[pulumi.Input[builtins.str]] = None,
                 note_events: Optional[pulumi.Input[builtins.bool]] = None,
                 notify_only_broken_pipelines: Optional[pulumi.Input[builtins.bool]] = None,
                 notify_only_default_branch: Optional[pulumi.Input[builtins.bool]] = None,
                 pipeline_channel: Optional[pulumi.Input[builtins.str]] = None,
                 pipeline_events: Optional[pulumi.Input[builtins.bool]] = None,
                 project: Optional[pulumi.Input[builtins.str]] = None,
                 push_channel: Optional[pulumi.Input[builtins.str]] = None,
                 push_events: Optional[pulumi.Input[builtins.bool]] = None,
                 tag_push_channel: Optional[pulumi.Input[builtins.str]] = None,
                 tag_push_events: Optional[pulumi.Input[builtins.bool]] = None,
                 username: Optional[pulumi.Input[builtins.str]] = None,
                 webhook: Optional[pulumi.Input[builtins.str]] = None,
                 wiki_page_channel: Optional[pulumi.Input[builtins.str]] = None,
                 wiki_page_events: Optional[pulumi.Input[builtins.bool]] = None):
        """
        Input properties used for looking up and filtering IntegrationSlack resources.
        :param pulumi.Input[builtins.str] branches_to_be_notified: Branches to send notifications for. Valid options are "all", "default", "protected", and "default*and*protected".
        :param pulumi.Input[builtins.str] confidential_issue_channel: The name of the channel to receive confidential issue events notifications.
        :param pulumi.Input[builtins.bool] confidential_issues_events: Enable notifications for confidential issues events.
        :param pulumi.Input[builtins.str] confidential_note_channel: The name of the channel to receive confidential note events notifications.
        :param pulumi.Input[builtins.bool] confidential_note_events: Enable notifications for confidential note events.
        :param pulumi.Input[builtins.str] issue_channel: The name of the channel to receive issue events notifications.
        :param pulumi.Input[builtins.bool] issues_events: Enable notifications for issues events.
        :param pulumi.Input[builtins.bool] job_events: Enable notifications for job events. **ATTENTION**: This attribute is currently not being submitted to the GitLab API, due to https://gitlab.com/gitlab-org/api/client-go/issues/1354.
        :param pulumi.Input[builtins.str] merge_request_channel: The name of the channel to receive merge request events notifications.
        :param pulumi.Input[builtins.bool] merge_requests_events: Enable notifications for merge requests events.
        :param pulumi.Input[builtins.str] note_channel: The name of the channel to receive note events notifications.
        :param pulumi.Input[builtins.bool] note_events: Enable notifications for note events.
        :param pulumi.Input[builtins.bool] notify_only_broken_pipelines: Send notifications for broken pipelines.
        :param pulumi.Input[builtins.bool] notify_only_default_branch: This parameter has been replaced with `branches_to_be_notified`.
        :param pulumi.Input[builtins.str] pipeline_channel: The name of the channel to receive pipeline events notifications.
        :param pulumi.Input[builtins.bool] pipeline_events: Enable notifications for pipeline events.
        :param pulumi.Input[builtins.str] project: ID of the project you want to activate integration on.
        :param pulumi.Input[builtins.str] push_channel: The name of the channel to receive push events notifications.
        :param pulumi.Input[builtins.bool] push_events: Enable notifications for push events.
        :param pulumi.Input[builtins.str] tag_push_channel: The name of the channel to receive tag push events notifications.
        :param pulumi.Input[builtins.bool] tag_push_events: Enable notifications for tag push events.
        :param pulumi.Input[builtins.str] username: Username to use.
        :param pulumi.Input[builtins.str] webhook: Webhook URL (Example, https://hooks.slack.com/services/...). This value cannot be imported.
        :param pulumi.Input[builtins.str] wiki_page_channel: The name of the channel to receive wiki page events notifications.
        :param pulumi.Input[builtins.bool] wiki_page_events: Enable notifications for wiki page events.
        """
        if branches_to_be_notified is not None:
            pulumi.set(__self__, "branches_to_be_notified", branches_to_be_notified)
        if confidential_issue_channel is not None:
            pulumi.set(__self__, "confidential_issue_channel", confidential_issue_channel)
        if confidential_issues_events is not None:
            pulumi.set(__self__, "confidential_issues_events", confidential_issues_events)
        if confidential_note_channel is not None:
            pulumi.set(__self__, "confidential_note_channel", confidential_note_channel)
        if confidential_note_events is not None:
            pulumi.set(__self__, "confidential_note_events", confidential_note_events)
        if issue_channel is not None:
            pulumi.set(__self__, "issue_channel", issue_channel)
        if issues_events is not None:
            pulumi.set(__self__, "issues_events", issues_events)
        if job_events is not None:
            pulumi.set(__self__, "job_events", job_events)
        if merge_request_channel is not None:
            pulumi.set(__self__, "merge_request_channel", merge_request_channel)
        if merge_requests_events is not None:
            pulumi.set(__self__, "merge_requests_events", merge_requests_events)
        if note_channel is not None:
            pulumi.set(__self__, "note_channel", note_channel)
        if note_events is not None:
            pulumi.set(__self__, "note_events", note_events)
        if notify_only_broken_pipelines is not None:
            pulumi.set(__self__, "notify_only_broken_pipelines", notify_only_broken_pipelines)
        if notify_only_default_branch is not None:
            warnings.warn("""use 'branches_to_be_notified' argument instead""", DeprecationWarning)
            pulumi.log.warn("""notify_only_default_branch is deprecated: use 'branches_to_be_notified' argument instead""")
        if notify_only_default_branch is not None:
            pulumi.set(__self__, "notify_only_default_branch", notify_only_default_branch)
        if pipeline_channel is not None:
            pulumi.set(__self__, "pipeline_channel", pipeline_channel)
        if pipeline_events is not None:
            pulumi.set(__self__, "pipeline_events", pipeline_events)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if push_channel is not None:
            pulumi.set(__self__, "push_channel", push_channel)
        if push_events is not None:
            pulumi.set(__self__, "push_events", push_events)
        if tag_push_channel is not None:
            pulumi.set(__self__, "tag_push_channel", tag_push_channel)
        if tag_push_events is not None:
            pulumi.set(__self__, "tag_push_events", tag_push_events)
        if username is not None:
            pulumi.set(__self__, "username", username)
        if webhook is not None:
            pulumi.set(__self__, "webhook", webhook)
        if wiki_page_channel is not None:
            pulumi.set(__self__, "wiki_page_channel", wiki_page_channel)
        if wiki_page_events is not None:
            pulumi.set(__self__, "wiki_page_events", wiki_page_events)

    @property
    @pulumi.getter(name="branchesToBeNotified")
    def branches_to_be_notified(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Branches to send notifications for. Valid options are "all", "default", "protected", and "default*and*protected".
        """
        return pulumi.get(self, "branches_to_be_notified")

    @branches_to_be_notified.setter
    def branches_to_be_notified(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "branches_to_be_notified", value)

    @property
    @pulumi.getter(name="confidentialIssueChannel")
    def confidential_issue_channel(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the channel to receive confidential issue events notifications.
        """
        return pulumi.get(self, "confidential_issue_channel")

    @confidential_issue_channel.setter
    def confidential_issue_channel(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "confidential_issue_channel", value)

    @property
    @pulumi.getter(name="confidentialIssuesEvents")
    def confidential_issues_events(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Enable notifications for confidential issues events.
        """
        return pulumi.get(self, "confidential_issues_events")

    @confidential_issues_events.setter
    def confidential_issues_events(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "confidential_issues_events", value)

    @property
    @pulumi.getter(name="confidentialNoteChannel")
    def confidential_note_channel(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the channel to receive confidential note events notifications.
        """
        return pulumi.get(self, "confidential_note_channel")

    @confidential_note_channel.setter
    def confidential_note_channel(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "confidential_note_channel", value)

    @property
    @pulumi.getter(name="confidentialNoteEvents")
    def confidential_note_events(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Enable notifications for confidential note events.
        """
        return pulumi.get(self, "confidential_note_events")

    @confidential_note_events.setter
    def confidential_note_events(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "confidential_note_events", value)

    @property
    @pulumi.getter(name="issueChannel")
    def issue_channel(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the channel to receive issue events notifications.
        """
        return pulumi.get(self, "issue_channel")

    @issue_channel.setter
    def issue_channel(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "issue_channel", value)

    @property
    @pulumi.getter(name="issuesEvents")
    def issues_events(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Enable notifications for issues events.
        """
        return pulumi.get(self, "issues_events")

    @issues_events.setter
    def issues_events(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "issues_events", value)

    @property
    @pulumi.getter(name="jobEvents")
    def job_events(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Enable notifications for job events. **ATTENTION**: This attribute is currently not being submitted to the GitLab API, due to https://gitlab.com/gitlab-org/api/client-go/issues/1354.
        """
        return pulumi.get(self, "job_events")

    @job_events.setter
    def job_events(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "job_events", value)

    @property
    @pulumi.getter(name="mergeRequestChannel")
    def merge_request_channel(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the channel to receive merge request events notifications.
        """
        return pulumi.get(self, "merge_request_channel")

    @merge_request_channel.setter
    def merge_request_channel(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "merge_request_channel", value)

    @property
    @pulumi.getter(name="mergeRequestsEvents")
    def merge_requests_events(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Enable notifications for merge requests events.
        """
        return pulumi.get(self, "merge_requests_events")

    @merge_requests_events.setter
    def merge_requests_events(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "merge_requests_events", value)

    @property
    @pulumi.getter(name="noteChannel")
    def note_channel(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the channel to receive note events notifications.
        """
        return pulumi.get(self, "note_channel")

    @note_channel.setter
    def note_channel(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "note_channel", value)

    @property
    @pulumi.getter(name="noteEvents")
    def note_events(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Enable notifications for note events.
        """
        return pulumi.get(self, "note_events")

    @note_events.setter
    def note_events(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "note_events", value)

    @property
    @pulumi.getter(name="notifyOnlyBrokenPipelines")
    def notify_only_broken_pipelines(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Send notifications for broken pipelines.
        """
        return pulumi.get(self, "notify_only_broken_pipelines")

    @notify_only_broken_pipelines.setter
    def notify_only_broken_pipelines(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "notify_only_broken_pipelines", value)

    @property
    @pulumi.getter(name="notifyOnlyDefaultBranch")
    @_utilities.deprecated("""use 'branches_to_be_notified' argument instead""")
    def notify_only_default_branch(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        This parameter has been replaced with `branches_to_be_notified`.
        """
        return pulumi.get(self, "notify_only_default_branch")

    @notify_only_default_branch.setter
    def notify_only_default_branch(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "notify_only_default_branch", value)

    @property
    @pulumi.getter(name="pipelineChannel")
    def pipeline_channel(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the channel to receive pipeline events notifications.
        """
        return pulumi.get(self, "pipeline_channel")

    @pipeline_channel.setter
    def pipeline_channel(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "pipeline_channel", value)

    @property
    @pulumi.getter(name="pipelineEvents")
    def pipeline_events(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Enable notifications for pipeline events.
        """
        return pulumi.get(self, "pipeline_events")

    @pipeline_events.setter
    def pipeline_events(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "pipeline_events", value)

    @property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        ID of the project you want to activate integration on.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter(name="pushChannel")
    def push_channel(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the channel to receive push events notifications.
        """
        return pulumi.get(self, "push_channel")

    @push_channel.setter
    def push_channel(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "push_channel", value)

    @property
    @pulumi.getter(name="pushEvents")
    def push_events(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Enable notifications for push events.
        """
        return pulumi.get(self, "push_events")

    @push_events.setter
    def push_events(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "push_events", value)

    @property
    @pulumi.getter(name="tagPushChannel")
    def tag_push_channel(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the channel to receive tag push events notifications.
        """
        return pulumi.get(self, "tag_push_channel")

    @tag_push_channel.setter
    def tag_push_channel(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "tag_push_channel", value)

    @property
    @pulumi.getter(name="tagPushEvents")
    def tag_push_events(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Enable notifications for tag push events.
        """
        return pulumi.get(self, "tag_push_events")

    @tag_push_events.setter
    def tag_push_events(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "tag_push_events", value)

    @property
    @pulumi.getter
    def username(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Username to use.
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "username", value)

    @property
    @pulumi.getter
    def webhook(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Webhook URL (Example, https://hooks.slack.com/services/...). This value cannot be imported.
        """
        return pulumi.get(self, "webhook")

    @webhook.setter
    def webhook(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "webhook", value)

    @property
    @pulumi.getter(name="wikiPageChannel")
    def wiki_page_channel(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the channel to receive wiki page events notifications.
        """
        return pulumi.get(self, "wiki_page_channel")

    @wiki_page_channel.setter
    def wiki_page_channel(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "wiki_page_channel", value)

    @property
    @pulumi.getter(name="wikiPageEvents")
    def wiki_page_events(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Enable notifications for wiki page events.
        """
        return pulumi.get(self, "wiki_page_events")

    @wiki_page_events.setter
    def wiki_page_events(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "wiki_page_events", value)


class IntegrationSlack(pulumi.CustomResource):

    pulumi_type = "gitlab:index/integrationSlack:IntegrationSlack"

    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 branches_to_be_notified: Optional[pulumi.Input[builtins.str]] = None,
                 confidential_issue_channel: Optional[pulumi.Input[builtins.str]] = None,
                 confidential_issues_events: Optional[pulumi.Input[builtins.bool]] = None,
                 confidential_note_channel: Optional[pulumi.Input[builtins.str]] = None,
                 confidential_note_events: Optional[pulumi.Input[builtins.bool]] = None,
                 issue_channel: Optional[pulumi.Input[builtins.str]] = None,
                 issues_events: Optional[pulumi.Input[builtins.bool]] = None,
                 merge_request_channel: Optional[pulumi.Input[builtins.str]] = None,
                 merge_requests_events: Optional[pulumi.Input[builtins.bool]] = None,
                 note_channel: Optional[pulumi.Input[builtins.str]] = None,
                 note_events: Optional[pulumi.Input[builtins.bool]] = None,
                 notify_only_broken_pipelines: Optional[pulumi.Input[builtins.bool]] = None,
                 notify_only_default_branch: Optional[pulumi.Input[builtins.bool]] = None,
                 pipeline_channel: Optional[pulumi.Input[builtins.str]] = None,
                 pipeline_events: Optional[pulumi.Input[builtins.bool]] = None,
                 project: Optional[pulumi.Input[builtins.str]] = None,
                 push_channel: Optional[pulumi.Input[builtins.str]] = None,
                 push_events: Optional[pulumi.Input[builtins.bool]] = None,
                 tag_push_channel: Optional[pulumi.Input[builtins.str]] = None,
                 tag_push_events: Optional[pulumi.Input[builtins.bool]] = None,
                 username: Optional[pulumi.Input[builtins.str]] = None,
                 webhook: Optional[pulumi.Input[builtins.str]] = None,
                 wiki_page_channel: Optional[pulumi.Input[builtins.str]] = None,
                 wiki_page_events: Optional[pulumi.Input[builtins.bool]] = None,
                 __props__=None):
        """
        The `IntegrationSlack` resource allows to manage the lifecycle of a project integration with Slack.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/project_integrations/#slack-notifications)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        awesome_project = gitlab.Project("awesome_project",
            name="awesome_project",
            description="My awesome project.",
            visibility_level="public")
        slack = gitlab.IntegrationSlack("slack",
            project=awesome_project.id,
            webhook="https://webhook.com",
            username="myuser",
            push_events=True,
            push_channel="push_chan")
        ```

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_integration_slack`. For example:

        terraform

        import {

          to = gitlab_integration_slack.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        You can import a gitlab_integration_slack.slack state using the project ID, e.g.

        ```sh
        $ pulumi import gitlab:index/integrationSlack:IntegrationSlack slack 1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] branches_to_be_notified: Branches to send notifications for. Valid options are "all", "default", "protected", and "default*and*protected".
        :param pulumi.Input[builtins.str] confidential_issue_channel: The name of the channel to receive confidential issue events notifications.
        :param pulumi.Input[builtins.bool] confidential_issues_events: Enable notifications for confidential issues events.
        :param pulumi.Input[builtins.str] confidential_note_channel: The name of the channel to receive confidential note events notifications.
        :param pulumi.Input[builtins.bool] confidential_note_events: Enable notifications for confidential note events.
        :param pulumi.Input[builtins.str] issue_channel: The name of the channel to receive issue events notifications.
        :param pulumi.Input[builtins.bool] issues_events: Enable notifications for issues events.
        :param pulumi.Input[builtins.str] merge_request_channel: The name of the channel to receive merge request events notifications.
        :param pulumi.Input[builtins.bool] merge_requests_events: Enable notifications for merge requests events.
        :param pulumi.Input[builtins.str] note_channel: The name of the channel to receive note events notifications.
        :param pulumi.Input[builtins.bool] note_events: Enable notifications for note events.
        :param pulumi.Input[builtins.bool] notify_only_broken_pipelines: Send notifications for broken pipelines.
        :param pulumi.Input[builtins.bool] notify_only_default_branch: This parameter has been replaced with `branches_to_be_notified`.
        :param pulumi.Input[builtins.str] pipeline_channel: The name of the channel to receive pipeline events notifications.
        :param pulumi.Input[builtins.bool] pipeline_events: Enable notifications for pipeline events.
        :param pulumi.Input[builtins.str] project: ID of the project you want to activate integration on.
        :param pulumi.Input[builtins.str] push_channel: The name of the channel to receive push events notifications.
        :param pulumi.Input[builtins.bool] push_events: Enable notifications for push events.
        :param pulumi.Input[builtins.str] tag_push_channel: The name of the channel to receive tag push events notifications.
        :param pulumi.Input[builtins.bool] tag_push_events: Enable notifications for tag push events.
        :param pulumi.Input[builtins.str] username: Username to use.
        :param pulumi.Input[builtins.str] webhook: Webhook URL (Example, https://hooks.slack.com/services/...). This value cannot be imported.
        :param pulumi.Input[builtins.str] wiki_page_channel: The name of the channel to receive wiki page events notifications.
        :param pulumi.Input[builtins.bool] wiki_page_events: Enable notifications for wiki page events.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: IntegrationSlackArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `IntegrationSlack` resource allows to manage the lifecycle of a project integration with Slack.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/project_integrations/#slack-notifications)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        awesome_project = gitlab.Project("awesome_project",
            name="awesome_project",
            description="My awesome project.",
            visibility_level="public")
        slack = gitlab.IntegrationSlack("slack",
            project=awesome_project.id,
            webhook="https://webhook.com",
            username="myuser",
            push_events=True,
            push_channel="push_chan")
        ```

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_integration_slack`. For example:

        terraform

        import {

          to = gitlab_integration_slack.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        You can import a gitlab_integration_slack.slack state using the project ID, e.g.

        ```sh
        $ pulumi import gitlab:index/integrationSlack:IntegrationSlack slack 1
        ```

        :param str resource_name: The name of the resource.
        :param IntegrationSlackArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(IntegrationSlackArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 branches_to_be_notified: Optional[pulumi.Input[builtins.str]] = None,
                 confidential_issue_channel: Optional[pulumi.Input[builtins.str]] = None,
                 confidential_issues_events: Optional[pulumi.Input[builtins.bool]] = None,
                 confidential_note_channel: Optional[pulumi.Input[builtins.str]] = None,
                 confidential_note_events: Optional[pulumi.Input[builtins.bool]] = None,
                 issue_channel: Optional[pulumi.Input[builtins.str]] = None,
                 issues_events: Optional[pulumi.Input[builtins.bool]] = None,
                 merge_request_channel: Optional[pulumi.Input[builtins.str]] = None,
                 merge_requests_events: Optional[pulumi.Input[builtins.bool]] = None,
                 note_channel: Optional[pulumi.Input[builtins.str]] = None,
                 note_events: Optional[pulumi.Input[builtins.bool]] = None,
                 notify_only_broken_pipelines: Optional[pulumi.Input[builtins.bool]] = None,
                 notify_only_default_branch: Optional[pulumi.Input[builtins.bool]] = None,
                 pipeline_channel: Optional[pulumi.Input[builtins.str]] = None,
                 pipeline_events: Optional[pulumi.Input[builtins.bool]] = None,
                 project: Optional[pulumi.Input[builtins.str]] = None,
                 push_channel: Optional[pulumi.Input[builtins.str]] = None,
                 push_events: Optional[pulumi.Input[builtins.bool]] = None,
                 tag_push_channel: Optional[pulumi.Input[builtins.str]] = None,
                 tag_push_events: Optional[pulumi.Input[builtins.bool]] = None,
                 username: Optional[pulumi.Input[builtins.str]] = None,
                 webhook: Optional[pulumi.Input[builtins.str]] = None,
                 wiki_page_channel: Optional[pulumi.Input[builtins.str]] = None,
                 wiki_page_events: Optional[pulumi.Input[builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = IntegrationSlackArgs.__new__(IntegrationSlackArgs)

            __props__.__dict__["branches_to_be_notified"] = branches_to_be_notified
            __props__.__dict__["confidential_issue_channel"] = confidential_issue_channel
            __props__.__dict__["confidential_issues_events"] = confidential_issues_events
            __props__.__dict__["confidential_note_channel"] = confidential_note_channel
            __props__.__dict__["confidential_note_events"] = confidential_note_events
            __props__.__dict__["issue_channel"] = issue_channel
            __props__.__dict__["issues_events"] = issues_events
            __props__.__dict__["merge_request_channel"] = merge_request_channel
            __props__.__dict__["merge_requests_events"] = merge_requests_events
            __props__.__dict__["note_channel"] = note_channel
            __props__.__dict__["note_events"] = note_events
            __props__.__dict__["notify_only_broken_pipelines"] = notify_only_broken_pipelines
            __props__.__dict__["notify_only_default_branch"] = notify_only_default_branch
            __props__.__dict__["pipeline_channel"] = pipeline_channel
            __props__.__dict__["pipeline_events"] = pipeline_events
            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
            __props__.__dict__["push_channel"] = push_channel
            __props__.__dict__["push_events"] = push_events
            __props__.__dict__["tag_push_channel"] = tag_push_channel
            __props__.__dict__["tag_push_events"] = tag_push_events
            __props__.__dict__["username"] = username
            if webhook is None and not opts.urn:
                raise TypeError("Missing required property 'webhook'")
            __props__.__dict__["webhook"] = webhook
            __props__.__dict__["wiki_page_channel"] = wiki_page_channel
            __props__.__dict__["wiki_page_events"] = wiki_page_events
            __props__.__dict__["job_events"] = None
        super(IntegrationSlack, __self__).__init__(
            'gitlab:index/integrationSlack:IntegrationSlack',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            branches_to_be_notified: Optional[pulumi.Input[builtins.str]] = None,
            confidential_issue_channel: Optional[pulumi.Input[builtins.str]] = None,
            confidential_issues_events: Optional[pulumi.Input[builtins.bool]] = None,
            confidential_note_channel: Optional[pulumi.Input[builtins.str]] = None,
            confidential_note_events: Optional[pulumi.Input[builtins.bool]] = None,
            issue_channel: Optional[pulumi.Input[builtins.str]] = None,
            issues_events: Optional[pulumi.Input[builtins.bool]] = None,
            job_events: Optional[pulumi.Input[builtins.bool]] = None,
            merge_request_channel: Optional[pulumi.Input[builtins.str]] = None,
            merge_requests_events: Optional[pulumi.Input[builtins.bool]] = None,
            note_channel: Optional[pulumi.Input[builtins.str]] = None,
            note_events: Optional[pulumi.Input[builtins.bool]] = None,
            notify_only_broken_pipelines: Optional[pulumi.Input[builtins.bool]] = None,
            notify_only_default_branch: Optional[pulumi.Input[builtins.bool]] = None,
            pipeline_channel: Optional[pulumi.Input[builtins.str]] = None,
            pipeline_events: Optional[pulumi.Input[builtins.bool]] = None,
            project: Optional[pulumi.Input[builtins.str]] = None,
            push_channel: Optional[pulumi.Input[builtins.str]] = None,
            push_events: Optional[pulumi.Input[builtins.bool]] = None,
            tag_push_channel: Optional[pulumi.Input[builtins.str]] = None,
            tag_push_events: Optional[pulumi.Input[builtins.bool]] = None,
            username: Optional[pulumi.Input[builtins.str]] = None,
            webhook: Optional[pulumi.Input[builtins.str]] = None,
            wiki_page_channel: Optional[pulumi.Input[builtins.str]] = None,
            wiki_page_events: Optional[pulumi.Input[builtins.bool]] = None) -> 'IntegrationSlack':
        """
        Get an existing IntegrationSlack resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] branches_to_be_notified: Branches to send notifications for. Valid options are "all", "default", "protected", and "default*and*protected".
        :param pulumi.Input[builtins.str] confidential_issue_channel: The name of the channel to receive confidential issue events notifications.
        :param pulumi.Input[builtins.bool] confidential_issues_events: Enable notifications for confidential issues events.
        :param pulumi.Input[builtins.str] confidential_note_channel: The name of the channel to receive confidential note events notifications.
        :param pulumi.Input[builtins.bool] confidential_note_events: Enable notifications for confidential note events.
        :param pulumi.Input[builtins.str] issue_channel: The name of the channel to receive issue events notifications.
        :param pulumi.Input[builtins.bool] issues_events: Enable notifications for issues events.
        :param pulumi.Input[builtins.bool] job_events: Enable notifications for job events. **ATTENTION**: This attribute is currently not being submitted to the GitLab API, due to https://gitlab.com/gitlab-org/api/client-go/issues/1354.
        :param pulumi.Input[builtins.str] merge_request_channel: The name of the channel to receive merge request events notifications.
        :param pulumi.Input[builtins.bool] merge_requests_events: Enable notifications for merge requests events.
        :param pulumi.Input[builtins.str] note_channel: The name of the channel to receive note events notifications.
        :param pulumi.Input[builtins.bool] note_events: Enable notifications for note events.
        :param pulumi.Input[builtins.bool] notify_only_broken_pipelines: Send notifications for broken pipelines.
        :param pulumi.Input[builtins.bool] notify_only_default_branch: This parameter has been replaced with `branches_to_be_notified`.
        :param pulumi.Input[builtins.str] pipeline_channel: The name of the channel to receive pipeline events notifications.
        :param pulumi.Input[builtins.bool] pipeline_events: Enable notifications for pipeline events.
        :param pulumi.Input[builtins.str] project: ID of the project you want to activate integration on.
        :param pulumi.Input[builtins.str] push_channel: The name of the channel to receive push events notifications.
        :param pulumi.Input[builtins.bool] push_events: Enable notifications for push events.
        :param pulumi.Input[builtins.str] tag_push_channel: The name of the channel to receive tag push events notifications.
        :param pulumi.Input[builtins.bool] tag_push_events: Enable notifications for tag push events.
        :param pulumi.Input[builtins.str] username: Username to use.
        :param pulumi.Input[builtins.str] webhook: Webhook URL (Example, https://hooks.slack.com/services/...). This value cannot be imported.
        :param pulumi.Input[builtins.str] wiki_page_channel: The name of the channel to receive wiki page events notifications.
        :param pulumi.Input[builtins.bool] wiki_page_events: Enable notifications for wiki page events.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _IntegrationSlackState.__new__(_IntegrationSlackState)

        __props__.__dict__["branches_to_be_notified"] = branches_to_be_notified
        __props__.__dict__["confidential_issue_channel"] = confidential_issue_channel
        __props__.__dict__["confidential_issues_events"] = confidential_issues_events
        __props__.__dict__["confidential_note_channel"] = confidential_note_channel
        __props__.__dict__["confidential_note_events"] = confidential_note_events
        __props__.__dict__["issue_channel"] = issue_channel
        __props__.__dict__["issues_events"] = issues_events
        __props__.__dict__["job_events"] = job_events
        __props__.__dict__["merge_request_channel"] = merge_request_channel
        __props__.__dict__["merge_requests_events"] = merge_requests_events
        __props__.__dict__["note_channel"] = note_channel
        __props__.__dict__["note_events"] = note_events
        __props__.__dict__["notify_only_broken_pipelines"] = notify_only_broken_pipelines
        __props__.__dict__["notify_only_default_branch"] = notify_only_default_branch
        __props__.__dict__["pipeline_channel"] = pipeline_channel
        __props__.__dict__["pipeline_events"] = pipeline_events
        __props__.__dict__["project"] = project
        __props__.__dict__["push_channel"] = push_channel
        __props__.__dict__["push_events"] = push_events
        __props__.__dict__["tag_push_channel"] = tag_push_channel
        __props__.__dict__["tag_push_events"] = tag_push_events
        __props__.__dict__["username"] = username
        __props__.__dict__["webhook"] = webhook
        __props__.__dict__["wiki_page_channel"] = wiki_page_channel
        __props__.__dict__["wiki_page_events"] = wiki_page_events
        return IntegrationSlack(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="branchesToBeNotified")
    def branches_to_be_notified(self) -> pulumi.Output[builtins.str]:
        """
        Branches to send notifications for. Valid options are "all", "default", "protected", and "default*and*protected".
        """
        return pulumi.get(self, "branches_to_be_notified")

    @property
    @pulumi.getter(name="confidentialIssueChannel")
    def confidential_issue_channel(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The name of the channel to receive confidential issue events notifications.
        """
        return pulumi.get(self, "confidential_issue_channel")

    @property
    @pulumi.getter(name="confidentialIssuesEvents")
    def confidential_issues_events(self) -> pulumi.Output[builtins.bool]:
        """
        Enable notifications for confidential issues events.
        """
        return pulumi.get(self, "confidential_issues_events")

    @property
    @pulumi.getter(name="confidentialNoteChannel")
    def confidential_note_channel(self) -> pulumi.Output[builtins.str]:
        """
        The name of the channel to receive confidential note events notifications.
        """
        return pulumi.get(self, "confidential_note_channel")

    @property
    @pulumi.getter(name="confidentialNoteEvents")
    def confidential_note_events(self) -> pulumi.Output[builtins.bool]:
        """
        Enable notifications for confidential note events.
        """
        return pulumi.get(self, "confidential_note_events")

    @property
    @pulumi.getter(name="issueChannel")
    def issue_channel(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The name of the channel to receive issue events notifications.
        """
        return pulumi.get(self, "issue_channel")

    @property
    @pulumi.getter(name="issuesEvents")
    def issues_events(self) -> pulumi.Output[builtins.bool]:
        """
        Enable notifications for issues events.
        """
        return pulumi.get(self, "issues_events")

    @property
    @pulumi.getter(name="jobEvents")
    def job_events(self) -> pulumi.Output[builtins.bool]:
        """
        Enable notifications for job events. **ATTENTION**: This attribute is currently not being submitted to the GitLab API, due to https://gitlab.com/gitlab-org/api/client-go/issues/1354.
        """
        return pulumi.get(self, "job_events")

    @property
    @pulumi.getter(name="mergeRequestChannel")
    def merge_request_channel(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The name of the channel to receive merge request events notifications.
        """
        return pulumi.get(self, "merge_request_channel")

    @property
    @pulumi.getter(name="mergeRequestsEvents")
    def merge_requests_events(self) -> pulumi.Output[builtins.bool]:
        """
        Enable notifications for merge requests events.
        """
        return pulumi.get(self, "merge_requests_events")

    @property
    @pulumi.getter(name="noteChannel")
    def note_channel(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The name of the channel to receive note events notifications.
        """
        return pulumi.get(self, "note_channel")

    @property
    @pulumi.getter(name="noteEvents")
    def note_events(self) -> pulumi.Output[builtins.bool]:
        """
        Enable notifications for note events.
        """
        return pulumi.get(self, "note_events")

    @property
    @pulumi.getter(name="notifyOnlyBrokenPipelines")
    def notify_only_broken_pipelines(self) -> pulumi.Output[builtins.bool]:
        """
        Send notifications for broken pipelines.
        """
        return pulumi.get(self, "notify_only_broken_pipelines")

    @property
    @pulumi.getter(name="notifyOnlyDefaultBranch")
    @_utilities.deprecated("""use 'branches_to_be_notified' argument instead""")
    def notify_only_default_branch(self) -> pulumi.Output[builtins.bool]:
        """
        This parameter has been replaced with `branches_to_be_notified`.
        """
        return pulumi.get(self, "notify_only_default_branch")

    @property
    @pulumi.getter(name="pipelineChannel")
    def pipeline_channel(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The name of the channel to receive pipeline events notifications.
        """
        return pulumi.get(self, "pipeline_channel")

    @property
    @pulumi.getter(name="pipelineEvents")
    def pipeline_events(self) -> pulumi.Output[builtins.bool]:
        """
        Enable notifications for pipeline events.
        """
        return pulumi.get(self, "pipeline_events")

    @property
    @pulumi.getter
    def project(self) -> pulumi.Output[builtins.str]:
        """
        ID of the project you want to activate integration on.
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter(name="pushChannel")
    def push_channel(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The name of the channel to receive push events notifications.
        """
        return pulumi.get(self, "push_channel")

    @property
    @pulumi.getter(name="pushEvents")
    def push_events(self) -> pulumi.Output[builtins.bool]:
        """
        Enable notifications for push events.
        """
        return pulumi.get(self, "push_events")

    @property
    @pulumi.getter(name="tagPushChannel")
    def tag_push_channel(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The name of the channel to receive tag push events notifications.
        """
        return pulumi.get(self, "tag_push_channel")

    @property
    @pulumi.getter(name="tagPushEvents")
    def tag_push_events(self) -> pulumi.Output[builtins.bool]:
        """
        Enable notifications for tag push events.
        """
        return pulumi.get(self, "tag_push_events")

    @property
    @pulumi.getter
    def username(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Username to use.
        """
        return pulumi.get(self, "username")

    @property
    @pulumi.getter
    def webhook(self) -> pulumi.Output[builtins.str]:
        """
        Webhook URL (Example, https://hooks.slack.com/services/...). This value cannot be imported.
        """
        return pulumi.get(self, "webhook")

    @property
    @pulumi.getter(name="wikiPageChannel")
    def wiki_page_channel(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The name of the channel to receive wiki page events notifications.
        """
        return pulumi.get(self, "wiki_page_channel")

    @property
    @pulumi.getter(name="wikiPageEvents")
    def wiki_page_events(self) -> pulumi.Output[builtins.bool]:
        """
        Enable notifications for wiki page events.
        """
        return pulumi.get(self, "wiki_page_events")

